@@ -14,6 +14,7 @@
 #include <QTimer>
 #include <QDebug>
 #include <KProcess>
+#include <KLocalizedString>
 
 #ifndef Q_OS_WIN
 #include <signal.h>
@@ -47,7 +48,16 @@ void RSession::login()
     m_process->start(QStandardPaths::findExecutable(QLatin1String("cantor_rserver")));
 #endif
 
-    m_process->waitForStarted();
+    if (!m_process->waitForStarted())
+    {
+        changeStatus(Session::Disable);
+        emit error(i18n("Failed to start R, please check R installation."));
+        emit loginDone();
+        delete m_process;
+        m_process = nullptr;
+        return;
+    }
+
     m_process->waitForReadyRead();
     qDebug()<<m_process->readAllStandardOutput();
 
