@@ -1,20 +1,8 @@
-/*************************************************************************************
- *  Copyright (C) 2009 by Milian Wolff <mail@milianw.de>                               *
- *                                                                                   *
- *  This program is free software; you can redistribute it and/or                    *
- *  modify it under the terms of the GNU General Public License                      *
- *  as published by the Free Software Foundation; either version 2                   *
- *  of the License, or (at your option) any later version.                           *
- *                                                                                   *
- *  This program is distributed in the hope that it will be useful,                  *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
- *  GNU General Public License for more details.                                     *
- *                                                                                   *
- *  You should have received a copy of the GNU General Public License                *
- *  along with this program; if not, write to the Free Software                      *
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
- *************************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009 Milian Wolff <mail@milianw.de>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "qalculatesyntaxhelpobject.h"
 #include "settings.h"
@@ -40,20 +28,21 @@ void QalculateSyntaxHelpObject::fetchInformation()
     qDebug() << "HELP CALLED FOR:" << QLatin1String(cmd.c_str());
 
     if (cmd == "plot") {
-	setPlotInformation();
-	return;
+        setPlotInformation();
+        return;
     }
+
     if (cmd == "saveVariables") {
-	setSaveVariablesInformation();
-	return;
+        setSaveVariablesInformation();
+        return;
     }
+
     if (cmd == "loadVariables") {
-	setLoadVariablesInformation();
-	return;
+        setLoadVariablesInformation();
+        return;
     }
 
-    ExpressionItem *item = CALCULATOR->getActiveExpressionItem(cmd);
-
+    auto* item = CALCULATOR->getActiveExpressionItem(std::move(cmd));
     if (!item) {
         m_answer = i18n("No function, variable or unit with specified name exist.");
         return;
@@ -246,8 +235,6 @@ void QalculateSyntaxHelpObject::setPlotInformation()
     arguments += optionFormat3.arg(QLatin1String("xvar"), i18n("The name of the x variable. This must be an unknown variable"), defaultValue.arg(QLatin1String("x")));
 
     m_answer = title + desc + syntax + arguments;
-
-
 }
 
 void QalculateSyntaxHelpObject::setSaveVariablesInformation()
@@ -268,10 +255,8 @@ void QalculateSyntaxHelpObject::setLoadVariablesInformation()
     m_answer = title + desc + syntax + arguments;
 }
 
-
 QString QalculateSyntaxHelpObject::answer()
 {
     fetchInformation();
     return m_answer;
 }
-
